@@ -1,6 +1,6 @@
 {% extends "sub_keys_base.sql" %}
 {% block select %}
-SELECT {% if left %}y{% else %}x{% endif %}.{{ columns[-1] }} AS {{ columns[-1] }},
+SELECT {% if x %}x{% else %}y{% endif %}.{{ join_cols[-1] }} AS {{ join_cols[-1] }},
        COUNT(*)
 {% endblock %}
 {% block groupby %}
@@ -10,6 +10,6 @@ GROUP BY 1
 ORDER BY 2 DESC
 {% endblock %}
 {% block limit %}
-LIMIT {{ max_rows }}
+LIMIT {{ max_rows_column }}
 {% endblock %}
 
